<script setup lang="ts">

import {ScreenApi, ScreenQueueVO} from "@/api/ecg/screen";
import {CallApi, CallVO} from "@/api/ecg/call";
import {queueStatusConvert} from "@/utils/statusFormatter";
import {useCheckTypeStore} from "@/store/modules/checkType";

defineOptions({ name: 'bigscreen' })

const checkTypeStore = useCheckTypeStore()

const displayColInfo = ref<Map<number, String[]>>(new Map())

const mapColumnVsPatients = ref<Map<number, ScreenQueueVO[]>>(new Map());

let curSpeakPat : CallVO | null = null;

const getDisplayColInfo = async () => {
  const data = await ScreenApi.getDisplayColInfo()
  displayColInfo.value = data
}

const getList = async () => {
  const data = await ScreenApi.getBigScreenData()
  mapColumnVsPatients.value = data;
}

const startScrolling = () => {
  setInterval(() => {
    getList();
    if ( curSpeakPat === null ) {
      initiateSpeak()
    }
  }, 5000); // 每X秒滚动一次
}

onMounted( () => {
  getDisplayColInfo()
  startScrolling()
})

const onSpeachEndEvent = async (event) => {
  console.log("Speech ended... " + event.currentTarget.text);
  curSpeakPat!.called = 1
  await CallApi.updateCall(curSpeakPat!)
  initiateSpeak()
}

const initiateSpeak = async () => {
  curSpeakPat = await CallApi.getNextCall()
  if (curSpeakPat !== null) {
    console.info( curSpeakPat )
    speak("请、" + curSpeakPat.patName + "到" + curSpeakPat.roomName + "就诊");
  }
}

const speak = (msg) => {
  console.info("speak " + msg);
  var speech = new SpeechSynthesisUtterance()
  speech.text = msg + "。。。" + msg + "。。。" + msg  + "。。。"
  speech.pitch = 1 // 获取并设置话语的音调(0-2 默认1，值越大越尖锐,越低越低沉)
  speech.rate = 0.9 // 获取并设置说话的速度(0.1-10 默认1，值越大语速越快,越小语速越慢)
  speech.volume = 100 // 获取并设置说话的音量
  speech.lang = 'zh-CN' // 设置播放语言

  speech.onend = onSpeachEndEvent
  speechSynthesis.speak(speech)
}

const nameDesensitize = (patName) => {
  if (patName.length == 2) {
    //截取name 字符串截取第一个字符，
    return patName.substring(0, 1) + '*';
  } else if (patName.length == 3) {
    //截取第一个和第三个字符
    return patName.substring(0, 1) + '*' + patName.substring(2, 3);
  } else if (patName.length > 3) {
    //截取第一个和大于第4个字符
    return (
        patName.substring(0, 1) + '*' + '*' + patName.substring(3, patName.length)
    );
  }
}

// const listReady = ref<ScreenQueueVO[]>([]) // 列表的数据
// const listWaiting = ref<ScreenQueueVO[]>([]) // 列表的数据
// const listPassed = ref<ScreenQueueVO[]>([]) //

const getItemCssClass = (item: ScreenQueueVO) => {
  if (item.status === 5)  //已过号
    return "warning-row";
  else if (item.status === 7)  //已过号-安装
    return "warning-row";
  else
    return "";
}

</script>

<template>
  <div style="height: 100%; display:flex; flex-direction: column; height: 100vh; overflow-y: auto; padding-left: 5px; padding-right: 5px">
    <div style="display:flex; justify-content: center; align-items: center; background: var(--el-color-primary-light-7); font-size: 22px; ">
      <img height="40px" src="@/assets/imgs/jinhua.png"/>
      金华人民医院
    </div>
    <div style="display:flex; justify-content:space-around; align-items: flex-start; border: solid 2px var(--el-color-primary-light-7); font-size: 23px; ">
      <div v-for="[disColId, disNameList] of Object.entries(displayColInfo)" :key="disColId" style="flex: 1; flex-basis: 300px; height: 100%; border-left: solid 2px var(--el-color-primary-light-7) ">
        <!--{{disColId}}-->
        <div v-for="(dispName, dispName_index) in disNameList" :key="dispName_index">
          {{dispName}}
        </div>
      </div>
    </div>
    <div style="display:flex; justify-content:space-around; align-items: flex-start; flex-grow: 1; border: solid 2px var(--el-color-primary-light-7); font-size: 20px">
      <div v-for="[disColId2, columnPatientList] of Object.entries(mapColumnVsPatients)" :key="disColId2" style="flex: 1; flex-basis: 300px; height: 100%; border-left: solid 2px var(--el-color-primary-light-7) ">
        <div v-for="(item, index) in columnPatientList" :key="index" :class="getItemCssClass(item)">
          <span style="display:inline-block; width:60px;">{{checkTypeStore.getCheckTypeSeqPrefix(item.bookCheckType)}}{{item.bookSeqNum}}</span>
          <span style="display:inline-block; width:80px;">{{ nameDesensitize(item.patName) }} </span>
          <span style="display:inline-block; width:80px;">{{queueStatusConvert(item.status)}} </span>
          {{item.roomName}} {{item.bedNo}}
        </div>
      </div>
    </div>
    <div style="display:flex; justify-content: center; align-items: center; background: var(--el-color-primary-light-7);">
      <el-button @click="speak('欢迎使用')" >欢迎使用</el-button>
    </div>
  </div>
</template>

<style scoped lang="scss">
.el-header {
  background-color: var(--el-color-primary-light-7);
  color: #333;
  text-align: center;
  line-height: 40px;

  display: flex;
  align-items: center;
  justify-content: center;
}

.el-footer {
  //background-color: var(--el-color-primary-light-7);
  color: #333;
  text-align: center;
  line-height: 60px;
}

.el-aside {
  background-color: var(--el-color-primary-light-7);
  color: #333;
  text-align: center;
  line-height: 200px;
}

.el-main {
  //background-color: var(--el-color-primary-light-7);
  color: #333;
  text-align: center;
  line-height: 160px;
}

body > .el-container {
  margin-bottom: 40px;
}

.warning-row {
  background-color: var(--el-color-warning-light-9);
}

</style>
